@@ -148,22 +148,20 @@ def keyword_score(data,sample_data_tokenized, keyword_corpus):
 	data['keyword_score']=scores
 	return data
 
-def hashtag_score(data, sample_data_tokenized, hashtag_corpus):
-	scores = []
-	for i in range(len(sample_data_tokenized)):
-		score=0
-		for c in hashtag_corpus.hashtags:
-			for t in sample_data_tokenized[i]:
-				if c==t:
-					score+=1
-		try:
-			scores.append(score)
-		except ZeroDivisionError:
-			scores.append(0)
+def hashtag_score(data, hastags_corpus):
+	scores=[]
+	for hshtgs in data.hashtags:
+		score = 0
+		for h in hshtgs:
+			#print(h)
+			for H in hastags_corpus.hashtags:
+				if h == H:
+					score += 1
+    scores.append(score)
 	data['hashtag_score'] = scores
 	data['index'] = [i for i in range(len(data))]
 	data['names']= ['TWEET '+str(i) for i in range(len(data))]
-	return data	
+	return data
 	
 def terrorist_keywords_belonging(data):
 	temp = data[data['keyword_score']>0].reset_index(drop=True)
@@ -962,10 +960,8 @@ def NLP_analysis(data, keyword_corpus, hashtag_corpus):
 	tweets_df["terrorist_suggestion"][(tweets_df["terrorist_suggestion"]==1) & (tweets_df["polarity"] < -0.1) & (tweets_df["subjectivity"]>0.6)]= 2
 	data["per_terr_hash_key"] = len(tweets_df[tweets_df["terrorist_suggestion"]==2]) / len(tweets_df[tweets_df["terrorist_suggestion"]==1])
 	data["suggestion"] = "No terrorist"
-	print(data[["per_terr_hash_key","per_hash_key","suggestion"]])
-	print(data)
-	data["suggestion"][(data["per_terr_hash_key"] >0.7) & (data["per_hash_key"]>0.15)] = "Terrorist"
-	print(data)
+	if(data["per_terr_hash_key"] >0.7) & (data["per_hash_key"]>0.15):
+		data["suggestion"]="Terrorist"
 	return data,tweets_df
 	
 def more_tweets_required(df,consumerKey,consumerSecret,accessToken,accessTokenSecret):
@@ -979,7 +975,7 @@ def more_tweets_required(df,consumerKey,consumerSecret,accessToken,accessTokenSe
 	return df_evaluate
 
 	
-def evaluate_NLP_profiles(data,keyword_corpus, hastag_corpus):	
+def evaluate_NLP_profiles(data,keyword_corpus, hashtag_corpus):	
 	for i in range(len(data)):
 		profile_evaluated, tweets_df = NLP_analysis(data.iloc[i], keyword_corpus, hashtags_corpus)
 		data.iloc[i] = profile_evaluated	
